Skip to contents

The GitHub Actions workflow runs R CMD check on your package. It uses a wide range of platforms, which can be reduced by commenting out or deleting platforms in the matrix configuration.

Usage

gha_check_full(pkg = ".", overwrite = TRUE, cron_expr = "30 08 1 * *")

Examples from r-lib/actions.

Arguments

pkg

Path to a (subdirectory of an) R package.

overwrite

Overwrite the action if it was already present.

cron_expr

Valid cron expression. By default, the first day of the month at 08:30 AM. See Details.

Value

Invisibly returns NULL after writing a GitHub Actions workflow to <pkg>/.github/workflows.

Details

Use crontab.guru to check and create your own cron tag.

See also

GitHub Actions helpers: gha_pkgdown_branch(), gha_update_docs()

Examples

# \dontrun{
gha_check_full(cron_expr = "57 16 12 * *")
#>  Adding "R-version" to .github/.gitignore.
#> Warning: cannot open file '/tmp/RtmpbE1kC0/file1a0f13696044/.github/.gitignore': No such file or directory
#> Error in file(path, open = file_mode, encoding = "utf-8"): cannot open the connection
# }