Create a GitHub Actions workflow that documents and checks your package
Source:R/gha_update_docs.R
gha_update_docs.RdThe GitHub Actions workflow documents your package (see update_docs()),
checks it and deploys the package on a gh-pages branch.
Examples from r-lib/actions.
Details
Check https://github.com/actions/runner-images to see the available options.
See also
update_docs()documents and checks your package.gha_check_full()creates a full package check action.gha_pkgdown_branch()creates a pkgdown deployment action.
GitHub Actions helpers:
gha_check_full(),
gha_pkgdown_branch()
Examples
# \dontrun{
# With Ubuntu 20.04
gha_update_docs(platform = "ubuntu", version = "20.04")
#> ✔ Adding "R-version" to .github/.gitignore.
#> Warning: cannot open file '/tmp/RtmpbE1kC0/file1a0f13696044/.github/.gitignore': No such file or directory
#> Error in file(path, open = file_mode, encoding = "utf-8"): cannot open the connection
# }