Checks generated Rd file titles for sentence case and trailing periods.
Value
A data frame with one row per Rd file and
columns for the source path, title, sentence-case title, final character
and sentence-case check. Returns NULL if no Rd files
are found.
See also
update_docs() runs this check after roxygenizing the package.