Inspect generated Rd file titles for sentence case and trailing periods.
Value
A data frame with one row per Rd file and columns for the source path, title, sentence-case title, final character and sentence-case check.
See also
update_docs() runs this check after roxygenizing the package.