Create a GitHub Actions workflow that checks your package regularly
Source:R/gha_check_full.R
gha_check_full.RdThe GitHub Actions workflow runs R CMD check on your package.
It uses a wide range of platforms, which can be reduced by commenting out or
deleting platforms in the matrix configuration.
Examples from r-lib/actions.
Details
Use crontab.guru to check and create your own cron tag.
See also
gha_pkgdown_branch()creates a pkgdown deployment action.gha_update_docs()creates a documentation and deployment action.usethis::use_github_action()creates GitHub Actions workflows.
GitHub Actions helpers:
gha_pkgdown_branch(),
gha_update_docs()
Examples
# \dontrun{
gha_check_full(cron_expr = "57 16 12 * *")
#> ✔ Adding "R-version" to .github/.gitignore.
#> Warning: cannot open file '/tmp/RtmpbE1kC0/file1a0f13696044/.github/.gitignore': No such file or directory
#> Error in file(path, open = file_mode, encoding = "utf-8"): cannot open the connection
# }